@@ -243,7 +243,9 @@ ps_dostart(struct dhcpcd_ctx *ctx,
 	if (callback(recv_ctx) == -1)
 		goto errexit;
 
-	if (!(ctx->options & (DHCPCD_TEST | DHCPCD_DEBUG))) {
+	if (!(ctx->options & DHCPCD_DEBUG) &&
+	   (!(ctx->options & DHCPCD_TEST) || loggetopts() & LOGERR_QUIET))
+	{
 		freopen(_PATH_DEVNULL, "w", stdout);
 		freopen(_PATH_DEVNULL, "w", stderr);
 	}
